=======
History
=======

********
Releases
********


0.5.0 (2023-07-26)
__________________

Internal Changes
----------------

* Redefine packaging via pyproject.toml.

Bug Fixes
---------

* Fix bug when in oceantide.core.otis when indexing with a dask boolean array.


0.1.0 (2020-10-02)
__________________

* First release on PyPI.
